@@ -1,9 +1,19 @@
 from __future__ import unicode_literals
+from netmiko.dell.dell_dnos6 import DellDNOS6SSH
+from netmiko.dell.dell_dnos6 import DellDNOS6Telnet
 from netmiko.dell.dell_force10_ssh import DellForce10SSH
 from netmiko.dell.dell_os10_ssh import DellOS10SSH, DellOS10FileTransfer
 from netmiko.dell.dell_powerconnect import DellPowerConnectSSH
 from netmiko.dell.dell_powerconnect import DellPowerConnectTelnet
 from netmiko.dell.dell_isilon_ssh import DellIsilonSSH
 
-__all__ = ['DellForce10SSH', 'DellPowerConnectSSH', 'DellPowerConnectTelnet',
-           'DellOS10SSH', 'DellOS10FileTransfer', 'DellIsilonSSH']
+__all__ = [
+    "DellForce10SSH",
+    "DellPowerConnectSSH",
+    "DellPowerConnectTelnet",
+    "DellOS10SSH",
+    "DellOS10FileTransfer",
+    "DellIsilonSSH",
+    "DellDNOS6SSH",
+    "DellDNOS6Telnet",
+]
