@@ -1,4 +1,4 @@
 from __future__ import unicode_literals
 from netmiko.mellanox.mellanox_ssh import MellanoxSSH
 
-__all__ = ['MellanoxSSH']
+__all__ = ["MellanoxSSH"]
