@@ -1,4 +1,4 @@
 from __future__ import unicode_literals
 from netmiko.mrv.mrv_ssh import MrvOptiswitchSSH
 
-__all__ = ['MrvOptiswitchSSH']
+__all__ = ["MrvOptiswitchSSH"]
